Struct substrate_prometheus_endpoint::Registry [−][src]
pub struct Registry { /* fields omitted */ }Expand description
A struct for registering Prometheus collectors, collecting their metrics, and gathering
them into MetricFamilies for exposition.
Implementations
Create a new registry, with optional custom prefix and labels.
register registers a new Collector to be included in metrics
collection. It returns an error if the descriptors provided by the
Collector are invalid or if they — in combination with descriptors of
already registered Collectors — do not fulfill the consistency and
uniqueness criteria described in the documentation of Desc.
If the provided Collector is equal to a Collector already registered
(which includes the case of re-registering the same Collector), the
AlreadyReg error returns.
gather calls the Collect method of the registered Collectors and then
gathers the collected metrics into a lexicographically sorted slice
of MetricFamily protobufs.