Type Definition substrate_prometheus_endpoint::SourcedGauge [−][src]
pub type SourcedGauge<S> = SourcedMetric<Gauge, S>;Expand description
A gauge whose values are obtained from an existing source.
pub type SourcedGauge<S> = SourcedMetric<Gauge, S>;A gauge whose values are obtained from an existing source.